<?php

/**
 * @package     Joomla.Administrator
 * @subpackage  com_templates
 *
 * @copyright   (C) 2016 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\CMS\Language\Text;
use Joomla\Filesystem\File;

/** @var \Joomla\Component\Templates\Administrator\View\Template\HtmlView $this */
?>
<div id="template-manager-rename" class="container-fluid">
    <div class="mt-2">
        <div class="col-md-12">
            <div class="control-group">
                <div class="control-label">
                    <label for="new_name">
                        <?php echo Text::_('COM_TEMPLATES_NEW_FILE_NAME')?>
                    </label>
                </div>
                <div class="controls">
                    <div class="input-group">
                        <input class="form-control" type="text" name="new_name" id="new_name" required>
                        <span class="input-group-text">.<?php echo File::getExt($this->fileName); ?></span>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
